@@ -1,19 +1,34 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Take",
     "Important" : "Belangrik",
     "Today" : "Vandag",
     "Week" : "Week",
     "All" : "Alle",
     "Current" : "Huidige",
     "Completed" : "Voltooid",
-    "Delete" : "Skrap",
+    "Tasks" : "Take",
+    "Share with users or groups" : "Deel met gebruikers of groepe",
+    "No users or groups" : "Geen gebruikers of groepe",
+    "can edit" : "kan wysig",
+    "New List" : "Nuwe lys",
     "Cancel" : "Kanselleer",
+    "Save" : "Stoor",
+    "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
+    "Edit" : "Wysig",
+    "Copied" : "Gekopieer",
+    "Can not copy" : "Kan nie kopieer nie",
+    "Download" : "Laai Af",
+    "Delete" : "Skrap",
+    "Unshare" : "Ontdeel",
+    "Visibility of Smart Collections" : "Sigbaarheid van Slimversamelings",
+    "Hidden" : "Versteek",
+    "Visible" : "Sigbaar",
+    "Automatic" : "Outomaties",
     "Change sort order" : "Verander sorteer volgorde",
-    "Default" : "Verstek",
-    "Due date" : "Sperdatum",
     "Start date" : "Begindatum",
+    "Due date" : "Sperdatum",
+    "Last modified" : "Laas gewysig",
     "Priority" : "Prioriteit",
     "Manually" : "Handmatig",
     "Alphabetically" : "Alfabeties",
@@ -24,15 +39,6 @@ OC.L10N.register(
     "Set due date" : "Stel sperdatum",
     "All day" : "Heeldag",
     "Task not found!" : "Taak nie gevind!",
-    "Edit" : "Wysig",
-    "Download" : "Laai Af",
-    "Save" : "Stoor",
-    "New List" : "Nuwe lys",
-    "An empty name is not allowed." : "’n Leë naam word nie toegestaan nie.",
-    "Settings" : "Instellings",
-    "Visibility of Smart Collections" : "Sigbaarheid van Slimversamelings",
-    "Hidden" : "Versteek",
-    "Visible" : "Sigbaar",
-    "Automatic" : "Outomaties"
+    "An error occurred" : "'n Fout het voorgekom"
 },
 "nplurals=2; plural=(n != 1);");
