@@ -1,17 +1,28 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Xeres",
     "Important" : "Importante",
     "Today" : "Güei",
     "Week" : "Selmana",
     "All" : "Toos",
     "Current" : "Actual",
     "Completed" : "Completáu",
-    "Delete" : "Desaniciar",
+    "Tasks" : "Xeres",
+    "Share with users or groups" : "Compartir con usuarios y grupos",
+    "can edit" : "pue editar",
+    "New List" : "Nueva Llista",
     "Cancel" : "Encaboxar",
+    "Save" : "Guardar",
+    "An empty name is not allowed." : "Nun s'almite un nome baleru",
+    "Edit" : "Editar",
+    "Download" : "Baxar",
+    "Delete" : "Desaniciar",
+    "Unshare" : "Dexar de compartir",
+    "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
+    "Hidden" : "Anubríu",
+    "Visible" : "Visible",
+    "Automatic" : "Automáticu",
     "Change sort order" : "Camudar orde d'ordenación",
-    "Default" : "Predetermináu",
     "Priority" : "Prioridá",
     "Manually" : "A mano",
     "Alphabetically" : "Alfabéticamente",
@@ -22,15 +33,8 @@ OC.L10N.register(
     "Set due date" : "Afitar la data de caducidá",
     "All day" : "Tol día",
     "Task not found!" : "¡Xera non atopada!",
-    "Edit" : "Editar",
-    "Download" : "Baxar",
-    "Save" : "Guardar",
-    "New List" : "Nueva Llista",
-    "An empty name is not allowed." : "Nun s'almite un nome baleru",
-    "Settings" : "Axustes",
-    "Visibility of Smart Collections" : "Visibilidá de Coleiciones Intelixentes",
-    "Hidden" : "Anubríu",
-    "Visible" : "Visible",
-    "Automatic" : "Automáticu"
+    "When shared show full event" : "Amosar l'eventu completu al compartir",
+    "When shared show only busy" : "Amosar namás ocupáu al compartir",
+    "When shared hide this event" : "Anubrir l'eventu al compartir"
 },
 "nplurals=2; plural=(n != 1);");
