@@ -1,19 +1,38 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Tareas",
     "Important" : "Importante",
     "Today" : "Hoy",
     "Week" : "Semana",
     "All" : "Todos",
     "Current" : "Actual",
     "Completed" : "Completado",
-    "Delete" : "Borrar",
+    "Tasks" : "Tareas",
+    "Share with users or groups" : "Compartir con usuarios o grupos",
+    "No users or groups" : "No hay usuarios ni grupos.",
+    "can edit" : "poder editar",
+    "Unable to delete the share." : "No se puede eliminar el recurso compartido.",
+    "Unable to change permissions." : "No se pueden cambiar los permisos.",
+    "New List" : "Nueva Lista",
     "Cancel" : "Cancelar",
+    "Save" : "Guardar",
+    "An empty name is not allowed." : "No se permite un nombre vacío.",
+    "Edit" : "Editar",
+    "Copied" : "Copiado",
+    "Can not copy" : "No se puede copiar",
+    "Download" : "Descargar",
+    "Delete" : "Borrar",
+    "Unshare" : "No compartir",
+    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
+    "Hidden" : "Oculto",
+    "Visible" : "Visible",
+    "Automatic" : "Automático",
+    "No errors" : "Sin errores",
+    "Open your browser console for more details" : "Abra la consola de su navegador para más detalles",
     "Change sort order" : "Cambiar el criterio para ordenar",
-    "Default" : "Predeterminado",
-    "Due date" : "Fecha de vencimiento",
     "Start date" : "Fecha de inicio",
+    "Due date" : "Fecha de vencimiento",
+    "Last modified" : "Última modificación",
     "Priority" : "Prioridad",
     "Manually" : "Manualmente",
     "Alphabetically" : "Alfabéticamente",
@@ -23,15 +42,9 @@ OC.L10N.register(
     "Set due date" : "Establecer fecha de vencimiento",
     "All day" : "Todo el día",
     "Task not found!" : "¡Tarea no encontrada!",
-    "Edit" : "Editar",
-    "Download" : "Descargar",
-    "Save" : "Guardar",
-    "New List" : "Nueva Lista",
-    "An empty name is not allowed." : "No se permite un nombre vacío.",
-    "Settings" : "Configuraciones ",
-    "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
-    "Hidden" : "Oculto",
-    "Visible" : "Visible",
-    "Automatic" : "Automático"
+    "When shared show full event" : "Al compartir, mostrar el evento completo",
+    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
+    "When shared hide this event" : "Al compartir, ocultar este evento ",
+    "An error occurred" : "Ocurrió un error"
 },
 "nplurals=2; plural=(n != 1);");
