@@ -1,19 +1,34 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Ülesanded",
     "Important" : "Tähtis",
     "Today" : "Täna",
     "Week" : "Nädal",
     "All" : "Kõik",
     "Current" : "Praegune",
     "Completed" : "Lõpetatud",
-    "Delete" : "Kustuta",
+    "Tasks" : "Ülesanded",
+    "Share with users or groups" : "Jaga kasutajate või gruppidega",
+    "No users or groups" : "Ei ole kasutajaid või gruppe",
+    "can edit" : "saab redigeerida",
+    "Unshare with {displayName}" : "Lõpeta jagamine kasutajaga: {displayName}",
+    "New List" : "Uus nimekiri",
     "Cancel" : "Loobu",
+    "Save" : "Salvesta",
+    "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
+    "Edit" : "Muuda",
+    "Copy private link" : "Kopeeri privaatne link",
+    "Download" : "Lae alla",
+    "Delete" : "Kustuta",
+    "Unshare" : "Lõpeta jagamine",
+    "Visibility of Smart Collections" : "Nutikate kollektsioonide nähtavus",
+    "Hidden" : "Peidetud",
+    "Visible" : "Nähtav",
+    "Automatic" : "Automaatne",
     "Change sort order" : "Muuda sorteerimisjärjekorda",
-    "Default" : "Vaikeväärtus",
-    "Due date" : "Tähtaeg",
     "Start date" : "Alguskuupäev",
+    "Due date" : "Tähtaeg",
+    "Last modified" : "Viimati muudetud",
     "Priority" : "Prioriteet",
     "Manually" : "Käsitsi",
     "Alphabetically" : "Tähestikujärjekorras",
@@ -24,15 +39,9 @@ OC.L10N.register(
     "Set due date" : "Määra tähtaeg",
     "All day" : "Kogu päev",
     "Task not found!" : "Ülesannet ei leitud!",
-    "Edit" : "Muuda",
-    "Download" : "Lae alla",
-    "Save" : "Salvesta",
-    "New List" : "Uus nimekiri",
-    "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
-    "Settings" : "Seaded",
-    "Visibility of Smart Collections" : "Nutikate kollektsioonide nähtavus",
-    "Hidden" : "Peidetud",
-    "Visible" : "Nähtav",
-    "Automatic" : "Automaatne"
+    "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
+    "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
+    "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
+    "An error occurred" : "Tekkis tõrge"
 },
 "nplurals=2; plural=(n != 1);");
