@@ -1,23 +1,46 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "משימות",
     "Important" : "חשוב",
     "Today" : "היום",
     "Week" : "שבוע",
     "All" : "הכול",
     "Current" : "נוכחי",
     "Completed" : "הושלם",
+    "Tasks" : "משימות",
     "The Tasks app for Nextcloud" : "יישומון המשימות ל־Nextcloud",
-    "Delete" : "מחיקה",
+    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
+    "No users or groups" : "אין משתמשים או קבוצות",
+    "can edit" : "יש הרשאת עריכה",
+    "Unshare with {displayName}" : "ביטול שיתוף עם {displayName}",
+    "Unable to delete the share." : "לא ניתן למחוק את השיתוף.",
+    "Unable to change permissions." : "לא ניתן לשנות הרשאות.",
+    "New List" : "רשימה חדשה",
     "Cancel" : "ביטול",
+    "Save" : "שמירה",
+    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
+    "Edit" : "עריכה",
+    "Copy private link" : "העתקת קישור פרטי",
+    "Copied" : "הועתק",
+    "Can not copy" : "לא ניתן להעתיק",
+    "Download" : "הורדה",
+    "Delete" : "מחיקה",
+    "Unshare" : "ביטול שיתוף",
+    "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
+    "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
+    "Default list" : "רשימת בררת מחדל",
+    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
+    "Hidden" : "מוסתר",
+    "Visible" : "גלוי",
+    "Automatic" : "אוטומטי",
+    "No errors" : "אין שגיאות",
+    "Open your browser console for more details" : "נא לפתוח את המסוף של הדפדפן שלך לקבלת פרטים נוספים",
     "Load all completed tasks." : "טעינת כל המשימות שהושלמו.",
     "Change sort order" : "שינוי סדר מיון",
-    "Default" : "בררת מחדל",
-    "Due date" : "תאריך יעד",
-    "Sort by due date and summary." : "מיון לפי תאריך תפוגה ותקציר.",
     "Start date" : "תאריך התחלה",
     "Sort by start date and summary." : "מיון לפי תאריך התחלה ותקציר.",
+    "Due date" : "תאריך יעד",
+    "Sort by due date and summary." : "מיון לפי תאריך תפוגה ותקציר.",
     "Created date" : "תאריך יצירה",
     "Sort by created date and summary." : "מיון לפי תאריך יצירה ותקציר.",
     "Last modified" : "מועד שינוי אחרון",
@@ -32,8 +55,6 @@ OC.L10N.register(
     "Sort by summary and priority." : "מיון לפי תקציר ועדיפות.",
     "Task is completed" : "המשימה הושלמה",
     "{complete} % completed" : "{complete} % הושלמו",
-    "Toggle visibility of completed subtasks." : "החלפת מצב חשיפה של כל תת־המשימות שהושלמו.",
-    "Toggle visibility of all subtasks." : "החלפת מצב חשיפה של כל תת־המשימות.",
     "[Yesterday]" : "[אתמול]",
     "[Today]" : "[היום]",
     "[Tomorrow]" : "[מחר]",
@@ -48,6 +69,9 @@ OC.L10N.register(
     "Select categories" : "בחירת קטגוריות",
     "Add this as a new category" : "הוספת הקטגוריה הזאת כחדשה",
     "Task not found!" : "לא אותרה משימה!",
+    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
+    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
+    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
     "[Starts today]" : "[מתחילה היום]",
     "[Starts tomorrow]" : "[מתחילה מחר]",
     "[Starts on] LL" : "[מתחילה במועד] LL",
@@ -71,27 +95,10 @@ OC.L10N.register(
     "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
     "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
     "No priority assigned" : "לא הוגדרה עדיפות",
-    "Edit" : "עריכה",
-    "Copy private link" : "העתקת קישור פרטי",
-    "Copied" : "הועתק",
-    "Can not copy" : "לא ניתן להעתיק",
-    "Download" : "הורדה",
-    "Save" : "שמירה",
-    "New List" : "רשימה חדשה",
-    "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
-    "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
-    "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
-    "Settings" : "הגדרות",
-    "Default list" : "רשימת בררת מחדל",
-    "Visibility of Smart Collections" : "הצגה של אוספים חכמים",
-    "Hidden" : "מוסתר",
-    "Visible" : "גלוי",
-    "Automatic" : "אוטומטי",
     "Could not delete the task." : "לא ניתן למחוק את המשימה.",
     "Synchronizing to the server." : "מתבצע סנכרון מול השרת.",
     "Task successfully saved to server." : "המשימה נשמרה לשרת בהצלחה.",
     "Could not update the task." : "לא ניתן לעדכן את המשימה.",
-    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discared." : "לא ניתן לעדכן את המשימה כיוון שהיא נערכה בשרת. נא ללחוץ כדי לרענן אותה, השינויים המקומיים לא יישמרו.",
     "An error occurred" : "אירעה שגיאה"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
