@@ -7,8 +7,20 @@ OC.L10N.register(
     "All" : "Tote",
     "Current" : "Actual",
     "Completed" : "Completate",
-    "Delete" : "Deler",
+    "Share with users or groups" : "Compartir con usatores o gruppos",
+    "can edit" : "pote modificar",
+    "New List" : "Nove Lista",
     "Cancel" : "Cancellar",
+    "Save" : "Salveguardar",
+    "An empty name is not allowed." : "Un nomine vacue non es permittite.",
+    "Edit" : "Modificar",
+    "Download" : "Discargar",
+    "Delete" : "Deler",
+    "Unshare" : "Cessa de compartir",
+    "Visibility of Smart Collections" : "Visibilitate de Collectiones Intelligente",
+    "Hidden" : "Occultate",
+    "Visible" : "Visibile",
+    "Automatic" : "Automatic",
     "Change sort order" : "Cambiar ordine de classification",
     "Priority" : "Prioritate",
     "Manually" : "Manualmente",
@@ -16,15 +28,8 @@ OC.L10N.register(
     "Tomorrow" : "Deman",
     "Set start date" : "Assigna le data de initio",
     "Set due date" : "Assignar data debite",
-    "Edit" : "Modificar",
-    "Download" : "Discargar",
-    "Save" : "Salveguardar",
-    "New List" : "Nove Lista",
-    "An empty name is not allowed." : "Un nomine vacue non es permittite.",
-    "Settings" : "Configurationes",
-    "Visibility of Smart Collections" : "Visibilitate de Collectiones Intelligente",
-    "Hidden" : "Occultate",
-    "Visible" : "Visibile",
-    "Automatic" : "Automatic"
+    "When shared show full event" : "Quando compartite, monstrar evento integremente",
+    "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
+    "When shared hide this event" : "Quando compartite, celar iste evento"
 },
 "nplurals=2; plural=(n != 1);");
