@@ -1,19 +1,31 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "დავალებები",
     "Important" : "აუცილებელი",
     "Today" : "დღეს",
     "Week" : "კვირა",
     "All" : "ყველა",
     "Current" : "ამჟამინდელი",
     "Completed" : "დასრულებული",
-    "Delete" : "წაშლა",
+    "Tasks" : "დავალებები",
+    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
+    "can edit" : "შეუძლია შეცვლა",
+    "New List" : "ახალი სია",
     "Cancel" : "უარყოფა",
+    "Save" : "შენახვა",
+    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
+    "Edit" : "რედაქტირება",
+    "Download" : "ჩამოტვირთვა",
+    "Delete" : "წაშლა",
+    "Unshare" : "გაზიარების შეწყვეტა",
+    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
+    "Hidden" : "უჩინარი",
+    "Visible" : "ჩანს",
+    "Automatic" : "ავტომატური",
     "Change sort order" : "განლაგების შეცვლა",
-    "Default" : "საწყისი",
-    "Due date" : "განპირობებულია თარიღისთვის",
     "Start date" : "დაწყების თარიღი",
+    "Due date" : "განპირობებულია თარიღისთვის",
+    "Last modified" : "ბოლო ცვლილება",
     "Priority" : "პრიორიტეტი",
     "Manually" : "ხელით",
     "Alphabetically" : "ანბანის მიხედვით",
@@ -24,15 +36,8 @@ OC.L10N.register(
     "Set due date" : "განპირობებულია თარიღისთვის",
     "All day" : "მთელი დღე",
     "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
-    "Edit" : "რედაქტირება",
-    "Download" : "ჩამოტვირთვა",
-    "Save" : "შენახვა",
-    "New List" : "ახალი სია",
-    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
-    "Settings" : "პარამეტრები",
-    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
-    "Hidden" : "უჩინარი",
-    "Visible" : "ჩანს",
-    "Automatic" : "ავტომატური"
+    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
+    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
+    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა"
 },
 "nplurals=2; plural=(n!=1);");
