@@ -1,19 +1,38 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Uzdevumi",
     "Important" : "Svarīgi",
     "Today" : "Šodien",
     "Week" : "Nedēļa",
     "All" : "Visi",
     "Current" : "Pašreizējais",
     "Completed" : "Pabeigts",
-    "Delete" : "Dzēst",
+    "Tasks" : "Uzdevumi",
+    "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
+    "No users or groups" : "Nav lietotāji vai grupas",
+    "can edit" : "var rediģēt",
+    "Unable to delete the share." : "Nevar izdzēst kopīgošanu.",
+    "Unable to change permissions." : "Nevar mainīt atļaujas.",
+    "New List" : "Jauns saraksts",
     "Cancel" : "Atcelt",
+    "Save" : "Saglabāt",
+    "An empty name is not allowed." : "Nosaukums ir obligāts.",
+    "Edit" : "Rediģēt",
+    "Copied" : "Nokopēts",
+    "Can not copy" : "Nevar nokopēt",
+    "Download" : "Lejupielādēt",
+    "Delete" : "Dzēst",
+    "Unshare" : "Pārtraukt dalīšanos",
+    "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
+    "Hidden" : "Paslēpts",
+    "Visible" : "Redzams",
+    "Automatic" : "Automātisks",
+    "No errors" : "Nav kļūdu",
+    "Open your browser console for more details" : "Atveriet savas pārlūkprogrammas konsoli sīkākai informācijai",
     "Change sort order" : "Mainīt kārtošanas secību",
-    "Default" : "Noklusējuma",
-    "Due date" : "Izpildes datums",
     "Start date" : "Sākuma datums",
+    "Due date" : "Izpildes datums",
+    "Last modified" : "Pēdējoreiz modificēts",
     "Priority" : "Prioritāte",
     "Manually" : "Manuāli",
     "Alphabetically" : "Alfabētiskā secībā",
@@ -24,15 +43,9 @@ OC.L10N.register(
     "Set due date" : "Uzstādīt izpildes termiņu",
     "All day" : "Visas dienas",
     "Task not found!" : "Uzdevums nav atrasts!",
-    "Edit" : "Rediģēt",
-    "Download" : "Lejupielādēt",
-    "Save" : "Saglabāt",
-    "New List" : "Jauns saraksts",
-    "An empty name is not allowed." : "Nosaukums ir obligāts.",
-    "Settings" : "Iestatījumi",
-    "Visibility of Smart Collections" : "Viedo kolekciju redzamība",
-    "Hidden" : "Paslēpts",
-    "Visible" : "Redzams",
-    "Automatic" : "Automātisks"
+    "When shared show full event" : "Ja koplietots, tad rādīt pilnu notikumu",
+    "When shared show only busy" : "Ja koplietots, tad rādīt tikai aizņemts",
+    "When shared hide this event" : "Ja koplietots, tad paslēpt notikumu",
+    "An error occurred" : "Gadījās kļūda"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
