@@ -1,15 +1,17 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "කාර්යය",
     "Important" : "වැදගත්",
     "Today" : "අද",
     "Week" : "සතිය",
     "All" : "සියල්ල",
-    "Delete" : "මකා දමන්න",
+    "Tasks" : "කාර්යය",
+    "can edit" : "සංස්කරණය කළ හැක",
     "Cancel" : "එපා",
+    "Save" : "සුරකින්න",
     "Edit" : "සකසන්න",
     "Download" : "බාන්න",
-    "Save" : "සුරකින්න"
+    "Delete" : "මකා දමන්න",
+    "Unshare" : "නොබෙදු"
 },
 "nplurals=2; plural=(n != 1);");
