@@ -1,19 +1,33 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "Detyra",
     "Important" : "E rëndësishme",
     "Today" : "Sot",
     "Week" : "Javë",
     "All" : "Krejt",
     "Current" : "E tanishmja",
     "Completed" : "Të plotësuara",
-    "Delete" : "Fshije",
+    "Tasks" : "Detyra",
+    "Share with users or groups" : "Nda me përdoruesit ose grupet",
+    "can edit" : "mund të modifikoni",
+    "New List" : "Listë e Re",
     "Cancel" : "Anuloje",
+    "Save" : "Ruaje",
+    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
+    "Edit" : "Përpunoni",
+    "Download" : "Shkarkoje",
+    "Delete" : "Fshije",
+    "Unshare" : "Hiqe ndarjen",
+    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
+    "Hidden" : "I padukshëm",
+    "Visible" : "I dukshëm",
+    "Automatic" : "Automatike",
+    "No errors" : "Nuk ka gabime",
+    "Open your browser console for more details" : "Hapni panelin e komandimit të shfletuesit tuaj për më shumë detaje",
     "Change sort order" : "Ndryshoni rend renditjeje",
-    "Default" : "Parazgjedhje",
-    "Due date" : "Datë përfundimi",
     "Start date" : "Datë nisjeje",
+    "Due date" : "Datë përfundimi",
+    "Last modified" : "Ndryshuar së fundmi",
     "Priority" : "Përparësi",
     "Manually" : "Dorazi",
     "Alphabetically" : "Alfabetikisht",
@@ -24,15 +38,8 @@ OC.L10N.register(
     "Set due date" : "Caktoni datë mbarimi",
     "All day" : "Gjithë ditën",
     "Task not found!" : "S’u gjet punë!",
-    "Edit" : "Përpunoni",
-    "Download" : "Shkarkoje",
-    "Save" : "Ruaje",
-    "New List" : "Listë e Re",
-    "An empty name is not allowed." : "Nuk lejohet emër i zbrazët.",
-    "Settings" : "Rregullime",
-    "Visibility of Smart Collections" : "Dukshmëri Koleksionesh të Mençura",
-    "Hidden" : "I padukshëm",
-    "Visible" : "I dukshëm",
-    "Automatic" : "Automatike"
+    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
+    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
+    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari"
 },
 "nplurals=2; plural=(n != 1);");
