@@ -1,19 +1,30 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "งาน",
     "Important" : "สำคัญ",
     "Today" : "วันนี้",
     "Week" : "สัปดาห์",
     "All" : "ทั้งหมด",
     "Current" : "ปัจจุบัน",
     "Completed" : "เสร็จสมบูรณ์",
-    "Delete" : "ลบ",
+    "Tasks" : "งาน",
+    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
+    "can edit" : "สามารถแก้ไข",
+    "New List" : "รายชื่อใหม่",
     "Cancel" : "ยกเลิก",
+    "Save" : "บันทึก",
+    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
+    "Edit" : "แก้ไข",
+    "Download" : "ดาวน์โหลด",
+    "Delete" : "ลบ",
+    "Unshare" : "ยกเลิกการแชร์",
+    "Visibility of Smart Collections" : "การแสดงผลของสมาร์ทคอลเลกชัน",
+    "Hidden" : "ซ่อน",
+    "Visible" : "มองเห็นได้",
+    "Automatic" : "อัตโนมัติ",
     "Change sort order" : "เปลี่ยนการเรียงลำดับ",
-    "Default" : "ค่าเริ่มต้น",
-    "Due date" : "วันที่ครบกำหนด",
     "Start date" : "วันที่เริ่มต้น",
+    "Due date" : "วันที่ครบกำหนด",
     "Priority" : "ลำดับความสำคัญ",
     "Manually" : "ทำด้วยตนเอง",
     "Alphabetically" : "เรียงตามตัวอักษร",
@@ -22,15 +33,8 @@ OC.L10N.register(
     "Set start date" : "วันที่เริ่มต้นการตั้งค่า",
     "Set due date" : "ระบุวันครบกำหนด",
     "Task not found!" : "ไม่พบงาน!",
-    "Edit" : "แก้ไข",
-    "Download" : "ดาวน์โหลด",
-    "Save" : "บันทึก",
-    "New List" : "รายชื่อใหม่",
-    "An empty name is not allowed." : "ชื่อห้ามปล่อยว่าง",
-    "Settings" : "ตั้งค่า",
-    "Visibility of Smart Collections" : "การแสดงผลของสมาร์ทคอลเลกชัน",
-    "Hidden" : "ซ่อน",
-    "Visible" : "มองเห็นได้",
-    "Automatic" : "อัตโนมัติ"
+    "When shared show full event" : "เมื่อแชร์จะแสดงกิจกรรมทั้งหมด",
+    "When shared show only busy" : "เมื่อแชร์จะแสดงเฉพาะไม่ว่าง",
+    "When shared hide this event" : "เมื่อแชร์จะซ่อนกิจกรรมนี้"
 },
 "nplurals=1; plural=0;");
