@@ -1,16 +1,16 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "ۋەزىپەلەر",
     "Important" : "مۇھىم",
     "Today" : "بۈگۈن",
     "Week" : "ھەپتە",
     "All" : "ھەممىسى",
-    "Delete" : "ئۆچۈر",
+    "Tasks" : "ۋەزىپەلەر",
     "Cancel" : "ۋاز كەچ",
-    "Default" : "كۆڭۈلدىكى",
+    "Save" : "ساقلا",
     "Edit" : "تەھرىر",
     "Download" : "چۈشۈر",
-    "Save" : "ساقلا"
+    "Delete" : "ئۆچۈر",
+    "Unshare" : "ھەمبەھىرلىمە"
 },
 "nplurals=1; plural=0;");
