@@ -1,22 +1,47 @@
 OC.L10N.register(
     "tasks",
     {
-    "Tasks" : "任务",
     "Important" : "重要",
     "Today" : "今天",
     "Week" : "星期",
     "All" : "全部",
     "Current" : "当前",
     "Completed" : "完成",
+    "Tasks" : "任务",
     "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
-    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "在启用后，Nextcloud 应用菜单中将显示一个新的“任务”菜单。从那里，您可以添加和删除任务，编辑其标题，描述，开始和截止日期，提醒时间，将其标记为重要，并添加注释。任务可以在用户之间共享。可以使用 CalDav 同步任务（每个任务列表链接到 Nextcloud 日历，将其同步到本地客户端 - Thunderbird，Evolution，KDE Kontact，iCal ... - 只需将日历添加为客户端中的远程日历）。您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
+    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "启用后，新的“任务”菜单将出现在您的 Nextcloud 应用程序菜单中。 在这里，您可以添加和删除任务，编辑任务的标题，描述，开始日期和截止日期并将其标记为重要。 任务可以在用户之间共享。 可以使用 CalDav 同步任务（每个任务列表都链接到 Nextcloud 日历，以将其同步到本地客户端 - Thunderbird，Evolution，KDE Kontact，iCal … - 只需将日历添加为客户端中的远程日历即可）。 您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
     "Share with users or groups" : "和用户或者群组共享",
     "No users or groups" : "无用户或群组",
     "can edit" : "可编辑",
+    "Unshare with {displayName}" : "取消与{displayName}的共享",
     "Unable to delete the share." : "无法删除此共享。",
     "Unable to change permissions." : "无法修改权限。",
-    "Delete" : "删除",
+    "Add List…" : "添加列表 ...",
+    "New List" : "新列表",
     "Cancel" : "取消",
+    "Save" : "保存",
+    "The name \"{calendar}\" is already used." : "名称 \"{calendar}\" 已被使用。",
+    "An empty name is not allowed." : "不允许使用空名称。",
+    "Edit" : "编辑",
+    "Copy private link" : "复制私人链接",
+    "Copied" : "已复制",
+    "Can not copy" : "无法复制",
+    "Download" : "下载",
+    "Delete" : "删除",
+    "Unshare" : "取消共享",
+    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "此操作将删除日历\"{calendar}\"以及所有相应的事件和任务。",
+    "This will unshare the calendar \"{calendar}\"." : "这将取消共享日历“{calendar}”。",
+    "Calendar link copied to clipboard." : "日历链接已复制到剪贴板。",
+    "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
+    "An error occurred, unable to delete the calendar." : "发生错误，无法删除日历。",
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["在{countdown}秒内删除日历"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["在 {countdown} 秒内取消共享日历"],
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
+    "Default list" : "默认列表",
+    "Visibility of Smart Collections" : "智能集合的可见性",
+    "Hidden" : "隐藏",
+    "Visible" : "可见",
+    "Automatic" : "自动",
     "Delete all completed tasks." : "删除所有已完成任务。",
     "Delete completed tasks." : "删除已完成任务。",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "从日历 \"{calendar}\" 中删除所有已完成任务。",
@@ -26,12 +51,12 @@ OC.L10N.register(
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["无法删除 {failedCount} 个任务。"],
     "Load all completed tasks." : "载入所有已完成任务。",
     "Change sort order" : "更改排序",
-    "Default" : "默认",
+    "Relevance" : "相关联",
     "Sort by completed state, due date, priority, start date and summary." : "按已完成状态，截止日期，优先级，开始日期及概况排序",
-    "Due date" : "截止日期",
-    "Sort by due date and summary." : "按到期日及概况排序",
     "Start date" : "开始日期",
     "Sort by start date and summary." : "按开始日期及概况排序",
+    "Due date" : "截止日期",
+    "Sort by due date and summary." : "按到期日及概况排序",
     "Created date" : "创建日期",
     "Sort by created date and summary." : "按创建日期及概况排序",
     "Last modified" : "上一次更改",
@@ -42,16 +67,22 @@ OC.L10N.register(
     "Sort by priority and summary." : "按优先级和摘要排序。",
     "Manually" : "手动",
     "Sort by manual order." : "按手动顺序排序。",
-    "Alphabetically" : "字母序",
+    "Alphabetically" : "按字母顺序",
     "Sort by summary and priority." : "按摘要和优先级排序。",
     "Task is completed" : "任务完成",
     "{complete} % completed" : "{complete} % 已完成",
-    "Toggle visibility of completed subtasks." : "切换已完成子任务的可见性。",
-    "Toggle visibility of all subtasks." : "切换所有子任务的可见性。",
+    "Add subtask" : "添加子任务",
+    "Show subtasks" : "显示子任务",
+    "Hide subtasks" : "隐藏子任务",
+    "Show completed subtasks" : "显示已完成的子任务",
+    "Hide completed subtasks" : "隐藏已完成的子任务",
+    "Delete task" : "删除任务",
     "[Yesterday]" : "[昨天]",
     "[Today]" : "[今天]",
     "[Tomorrow]" : "[明天]",
     "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
+    "An error occurred, unable to delete the task." : "发生错误，无法删除任务。",
+    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["在 {countdown} 秒后删除任务"],
     "Add a task to \"{task}\"…" : "添加任务到 \"{task}\" ...",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n 任务完成"],
     "Add an important task to \"{calendar}\"…" : "添加重要任务到 \"{calendar}\" ...",
@@ -66,9 +97,17 @@ OC.L10N.register(
     "All day" : "所有天",
     "Select a calendar" : "选择一个日历",
     "Select a classification" : "选择类别",
+    "Select a status" : "选择一个状态",
     "Select categories" : "选择分类",
     "Add this as a new category" : "添加此项作为新的分类",
+    "Loading task from server." : "从服务器加载任务。",
     "Task not found!" : "没有任务！",
+    "When shared show full event" : "共享时显示完整事件",
+    "When shared show only busy" : "共享时仅显示进行中的事件",
+    "When shared hide this event" : "共享时隐藏本事件",
+    "Needs action" : "需要操作",
+    "In process" : "处理中",
+    "Canceled" : "已取消",
     "[Starts today]" : "[今天开始]",
     "[Starts tomorrow]" : "[明天开始]",
     "[Starts on] LL" : "[开始于] LL",
@@ -91,43 +130,22 @@ OC.L10N.register(
     "[Due on] LL [at] LT" : "[截止于] LL [的] LT",
     "[Was due yesterday at] LT" : "[已截止于昨天的] LT",
     "[Was due on] LL [at] LT" : "[已截止于] LL [的] LT",
+    "Last modified {date}" : "上一次更改 {date}",
+    "Created {date}" : "创建日期 {date}",
+    "Completed {date}" : "完成日期 {date}",
     "No priority assigned" : "未设置优先级",
     "Priority {priority}: high" : "优先级 {priority}：高",
     "Priority {priority}: medium" : "优先级 {priority}：中",
     "Priority {priority}: low" : "优先级 {priority}：低",
     "{percent} % completed" : "{percent} % 已完成",
-    "When shared show full event" : "共享时显示完整事件",
-    "When shared show only busy" : "共享时仅显示进行中的事件",
-    "When shared hide this event" : "共享时隐藏本事件",
-    "Completed {date}" : "完成日期 {date}",
-    "Created {date}" : "创建日期 {date}",
-    "Last modified {date}" : "上一次更改 {date}",
-    "Edit" : "编辑",
-    "Copy private link" : "复制私人链接",
-    "Copied" : "已复制",
-    "Can not copy" : "无法复制",
-    "Download" : "下载",
-    "Save" : "保存",
-    "Add List…" : "添加列表 ...",
-    "New List" : "新列表",
-    "Calendar link copied to clipboard." : "日历链接已复制到剪贴板。",
-    "Calendar link could not be copied to clipboard." : "日历链接无法复制到剪贴板。",
-    "The name \"{calendar}\" is already used." : "名称 \"{calendar}\" 已被使用。",
-    "An empty name is not allowed." : "不允许使用空名称。",
-    "This will delete the calendar \"{calendar}\" and all corresponding events and tasks." : "此操作将删除日历\"{calendar}\"以及所有相应的事件和任务。",
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
-    "Settings" : "设置",
-    "Default list" : "默认列表",
-    "Visibility of Smart Collections" : "智能集合的可见性",
-    "Hidden" : "隐藏",
-    "Visible" : "可见",
-    "Automatic" : "自动",
+    "Successfully created the task." : "成功创建任务。",
     "Could not delete the task." : "无法删除任务。",
     "Synchronizing to the server." : "正在同步到服务器。",
     "Task successfully saved to server." : "任务已成功保存到服务器。",
     "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "无法更新任务，因为它已在服务器上被更改。请点击以刷新此任务，本地变更将被丢弃。",
     "Could not update the task." : "无法更新任务。",
-    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discared." : "无法更新任务，因为它已在服务器上被修改。请点击以刷新它，本地变更将被丢弃。",
+    "Successfully updated the task." : "成功更新任务。",
+    "Task successfully moved to new calendar." : "任务已成功移至新日历。",
     "An error occurred" : "发生了一个错误"
 },
 "nplurals=1; plural=0;");
